%{!?kernel_version: %{expand: %%define kernel_version %(uname -r)}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | perl -pe 's/^.*-(.*?)$/$1/g')}}

# Definitions for symvers files.
%define vmw_symvers_dir etc/vmware-tools/symvers
%define bld_symvers_file Modules.symvers

Name:         vmware-tools-vmhgfs
BuildRequires: kernel-source kernel-syms gcc make perl
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmhgfs kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.4.1.1
Release:      3
Source1:      vmhgfs-configModule.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

Source0:      vmhgfs.tar
Source2:      vmhgfs-vmware-PLDP-spec

%define kernel_version %(uname -r|perl -pe 's/^(.*)-.*?$/$1/g')

%define vmware_use_symvers_file 1

# Lock down flavors to build to just the current flavor.
%{expand: %%define current_flavor %(uname -r|perl -pe 's/^.*-(.*)$/$1/g')}
%suse_kernel_module_package -s %{SOURCE2} -x %{current_flavor}

%prep
%setup -n vmhgfs-only

%build
for flavor in %flavors_to_build; do
  VMCI_SYMVERS_FILE=/%{vmw_symvers_dir}/vmci-9.0.3.0-%{kernel_version}-$flavor

  rm -rf ../$flavor ../vmhgfs.o
  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor clean

  # For modules that depend on vmci, copy in the vmci symvers file
  # or die trying.
  # XXX: I can only handle dependency on one module's symvers file.
  if [ "vmhgfs" = "vsock" -o "vmhgfs" = "vmhgfs" ]; then
     if [ ! -e $VMCI_SYMVERS_FILE ]; then
        echo
        echo
        echo "
ERROR: Could not find $VMCI_SYMVERS_FILE.  This package relies on kernel symbols for the currently running kernel that are built from the vmware-tools-vmci source RPM package.  Please do the following:

- Rebuild the vmware-tools-vmci source RPM package.
- Install the resulting binary RPM from /usr/src/packages/RPMS/\$ARCH/.
- Rebuild this package again."
        echo
        echo
        exit 1
     fi
     cp -f $VMCI_SYMVERS_FILE ./%{bld_symvers_file}
  fi

  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor
  mkdir ../$flavor
  cp ../vmhgfs.o ../$flavor

  # Take the symvers file with us as well.
  cp ./%{bld_symvers_file} ../$flavor/%{bld_symvers_file}
done

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
for flavor in %flavors_to_build; do
  vmhgfs_SYMVERS_FILE=%{vmw_symvers_dir}/vmhgfs-1.4.1.1-%{kernel_version}-$flavor
  # Install the module and symvers file.
  install -m 644 -D ../$flavor/vmhgfs.o $RPM_BUILD_ROOT/lib/modules/%{kernel_version}-$flavor/updates/vmhgfs.ko
  install -m 644 -D ../$flavor/%{bld_symvers_file} $RPM_BUILD_ROOT/$vmhgfs_SYMVERS_FILE
done
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmhgfs.  The vmhgfs driver is the host-guest file system client which provides a file system interface using a specific namespace for guest user applications to perform file operations, to access or create new files which reside on the host. The vmhgfs driver communicates with the host-guest file system server which runs on the host.

%package common
Summary:      Contains the common files used by all the vmhgfs kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.5
Release:      3
Version:      8.6.5

%description common
 This package contains the common system configuration and scripts responsible for loading the vmhgfs kernel module.  The vmhgfs driver is the host-guest file system client which provides a file system interface using a specific namespace for guest user applications to perform file operations, to access or create new files which reside on the host. The vmhgfs driver communicates with the host-guest file system server which runs on the host.

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmhgfs ]; then
      /sbin/insserv -r vmhgfs >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-deconfig.pl --os=linux,sle,10 --kernel=%{kernel_version} --toDeconfigure=vmhgfs
   /usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-db.pl --os=linux,sle,10 --dbDelAnswer VMHGFS_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-db.pl --os=linux,sle,10 --dbAddAnswer VMHGFS_NAME,vmhgfs
/usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-config.pl --os=linux,sle,10 --kernel=%{kernel_version} --toConfigure=vmhgfs
if [ -e /etc/init.d/vmhgfs ]; then
   /sbin/insserv -f vmhgfs >/dev/null 2>&1
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmhgfs ]; then
      /sbin/insserv -r vmhgfs >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-deconfig.pl --os=linux,sle,10 --kernel=%{kernel_version} --toDeconfigure=vmhgfs
   /usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-db.pl --os=linux,sle,10 --dbDelAnswer VMHGFS_NAME
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-config.pl
/etc/init.d/vmhgfs
%dir /usr/lib/vmware-tools/moduleScripts/vmhgfs
%dir /usr/lib/vmware-tools/moduleScripts
%dir /usr/lib/vmware-tools
%dir /usr/lib
%dir /usr
%dir /etc/init.d
%dir /etc
